@@ -74,33 +74,10 @@ prep() {
   (cd ${topdir} && \
   tar xv${opt_decomp}f ${src_orig_pkg} ; \
   cd ${topdir} && \
-  patch -p0 < ${src_patch} 
-  && mkdirs )
-}
-conf() {
-  #(cd ${objdir} && \
-  #CFLAGS="${MY_CFLAGS}" LDFLAGS="${MY_LDFLAGS}" \
-  #${srcdir}/configure \
-  #--srcdir=${srcdir} --prefix=${prefix} \
-  #--exec-prefix=${prefix} --sysconfdir=${sysconfdir} \
-  #--libdir=${prefix}/lib --includedir=${prefix}/include \
-  #--mandir=${prefix}/share/man --infodir=${prefix}/share/info \
-  #--libexecdir='${sbindir}' --localstatedir=/var \
-  #--datadir='${prefix}/share'
-#)
-}
-build() {
-  #(cd ${objdir} && \
-  #CFLAGS="${MY_CFLAGS}" make )
-}
-check() {
-  #(cd ${objdir} && \
-  #make test | tee ${checkfile} 2>&1 )
-}
-clean() {
-  #(cd ${objdir} && \
-  #make clean )
+  patch -p0 < ${src_patch} && \
+  mkdirs )
 }
+
 install() {
   (cd ${objdir} && \
   #make install DESTDIR=${instdir} 
